# v_PVMismatch
 Vectorized version of SunPower's PVMismatch using dynamic programming. PVMismatch is an explicit IV & PV curve trace calculator for PV system circuits.
 
## Install & Setup
In a fresh Python virtual environment, simply run:

```bash
$ pip install -i https://test.pypi.org/simple/ v-PVMismatch
```

## Requirements

v_PVMismatch requires NumPy, and SciPy.

## Current Maintainer at Maxeon Solar

@k-bsub
